# Welcome to DeepXROMM!

## Getting started
1. Follow the steps on our [Installation](install.md) page to get the package and its dependencies set up
2. Follow the [Usage](usage.md) guide to start training DeepLabCut networks for your data
3. Visit our [Config file reference](config.md) to learn more about all of the different customization options available for training networks!
## Project layout

    dlc-proj/        # Files generated by DeepLabCut
    trainingdata/    # Trials for the network to train on
    trials/          # Trials for the network to analyze
